@@ -1,7 +1,7 @@
 //! HackRF One API.
 //!
 //! To get started take a look at [`HackRfOne::new`].
-#![doc(html_root_url = "https://docs.rs/hackrfone/0.2.0")]
+#![doc(html_root_url = "https://docs.rs/hackrfone/0.2.3")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(missing_docs)]
 
@@ -461,7 +461,7 @@ impl<MODE> HackRfOne<MODE> {
         if gain > 40 {
             Err(Error::Argument)
         } else {
-            let buf: [u8; 1] = self.read_control(Request::SetVgaGain, gain & !0x07, 0)?;
+            let buf: [u8; 1] = self.read_control(Request::SetLnaGain, 0, gain & !0x07)?;
             if buf[0] == 0 {
                 Err(Error::Argument)
             } else {
@@ -492,7 +492,7 @@ impl<MODE> HackRfOne<MODE> {
         if gain > 62 {
             Err(Error::Argument)
         } else {
-            let buf: [u8; 1] = self.read_control(Request::SetVgaGain, gain & !0b1, 0)?;
+            let buf: [u8; 1] = self.read_control(Request::SetVgaGain, 0, gain & !0b1)?;
             if buf[0] == 0 {
                 Err(Error::Argument)
             } else {
@@ -508,7 +508,7 @@ impl<MODE> HackRfOne<MODE> {
         if gain > 47 {
             Err(Error::Argument)
         } else {
-            let buf: [u8; 1] = self.read_control(Request::SetTxvgaGain, gain, 0)?;
+            let buf: [u8; 1] = self.read_control(Request::SetTxvgaGain, 0, gain)?;
             if buf[0] == 0 {
                 Err(Error::Argument)
             } else {
@@ -571,6 +571,7 @@ impl<MODE> HackRfOne<MODE> {
     /// ```
     pub fn into_rx_mode(mut self) -> Result<HackRfOne<RxMode>, Error> {
         self.set_transceiver_mode(TranscieverMode::Receive)?;
+        self.dh.claim_interface(0)?;
         Ok(HackRfOne {
             dh: self.dh,
             desc: self.desc,
@@ -585,7 +586,7 @@ impl HackRfOne<RxMode> {
     ///
     /// This uses a bulk transfer to get one MTU (maximum transmission unit)
     /// of data in a single shot.  The data format is pairs of signed 8-bit IQ.
-    /// Use the [`iq_to_cplx_i8`] or [`iq_to_cplx_f32`] helpes to convert the
+    /// Use the [`iq_to_cplx_i8`] or [`iq_to_cplx_f32`] helpers to convert the
     /// data to a more manageable format.
     ///
     /// Unlike `libhackrf` this does not spawn a sampling thread.
@@ -627,6 +628,7 @@ impl HackRfOne<RxMode> {
     /// # Ok::<(), hackrfone::Error>(())
     /// ```
     pub fn stop_rx(mut self) -> Result<HackRfOne<UnknownMode>, Error> {
+        self.dh.release_interface(0)?;
         self.set_transceiver_mode(TranscieverMode::Off)?;
         Ok(HackRfOne {
             dh: self.dh,
